@@ -8,4 +8,4 @@ class Event(ABC):
 class EventHandler(ABC):
     @abstractmethod
     def handle_event(self, event_to_handle: Event):
-        raise NotImplementedError
+        raise NotImplementedError()
